@@ -1,7 +1,7 @@
 package Moose::Policy;
 use Moose 'confess', 'blessed';
 
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub import {
@@ -66,6 +66,17 @@ Moose::Policy - Moose-mounted police
 
   # Foo now has (get, set)_bar methods as well as get_baz
 
+=head1 DEPRECATION NOTICE
+
+B<Moose::Policy is deprecated>.
+
+L<MooseX::FollowPBP> replaces the L<Moose::Policy::FollowPBP> module. The
+other policies included in this distribution do not yet have standalone MooseX
+modules, as of November, 2010.
+
+This module has not passed its tests since Moose 1.05, and will probably not
+be fixed.
+
 =head1 DESCRIPTION
 
 This module allows you to specify your project-wide or even company-wide 
